package com.yiboshi.science.entity;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiboshi.science.base.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotNull;
import java.util.Date;

/**
 * 单位表VO
 * 
 * @author lkl
 * @version 2021-08-26
 */
@Data
@EqualsAndHashCode(callSuper=true)
@ApiModel(description = "单位表VO")
public class ComUnit extends BaseEntity {

    /** 远程单位id */
    @ApiModelProperty(value = "远程单位id", position = 1)
    private Long longId;
    /** 上级单位Id */
    @ApiModelProperty(value = "上级单位Id", position = 1)
    private Long parentId;
    /** 树编码 */
    @ApiModelProperty(value = "树编码", position = 1 , required = true)
    @NotNull(message = "树编码不能为空")
    @Length(max=50, message = "树编码不能大于50")
    private String treeCode;
    /** 单位名称 */
    @ApiModelProperty(value = "单位名称", position = 2 )
    @Length(max=200, message = "单位名称不能大于200")
    private String unitName;
    /** 单位类型 */
    @ApiModelProperty(value = "单位类型", position = 3 )
    private Integer unitType;
    /** 是否直属单位 1是 */
    private Integer provinceSubjection;
    /** 单位性质 */
    @ApiModelProperty(value = "单位性质", position = 3 )
    private String unitNature;
    /** 状态 1正常 2 注销 */
    @ApiModelProperty(value = "状态 1正常 2 注销", position = 5)
    private Integer unitState;
    /** 单位地址 */
    @ApiModelProperty(value = "单位地址", position = 6 )
    @Length(max=200, message = "单位地址不能大于200")
    private String unitAddress;
    /** 邮编 */
    @ApiModelProperty(value = "邮编", position = 7 )
    @Length(max=100, message = "邮编不能大于100")
    private String postcode;
    /** 联系人姓名 */
    @ApiModelProperty(value = "联系人姓名", position = 8 )
    @Length(max=100, message = "联系人姓名不能大于100")
    private String linkName;
    /** 联系人电话 */
    @ApiModelProperty(value = "联系人电话", position = 9 )
    @Length(max=100, message = "联系人电话不能大于100")
    private String linkTel;
    /** 联系人邮箱 */
    @ApiModelProperty(value = "联系人邮箱", position = 10 )
    @Length(max=100, message = "联系人邮箱不能大于100")
    private String linkEmail;
    /** 申报项目数量配比 */
    @ApiModelProperty(value = "申报项目数量配比", position = 11 )
    private Integer projLimit;
    /** 备注 */
    @ApiModelProperty(value = "备注", position = 12 )
    @Length(max=200, message = "备注不能大于200")
    private String remark;
    /** 1 待审核，10 审核通过， 20 审核不通过 ，30 返回修改 */
    @ApiModelProperty(value = "审核结果", position = 6 )
    private Integer auditResult;
    /** 审核内容 */
    @ApiModelProperty(value = "审核内容", position = 5 )
    private String auditContent;
    /** 审核单位*/
    @ApiModelProperty(value = "审核单位", position = 28 )
    private String auditUnit;
    /** 审核人 */
    @ApiModelProperty(value = "审核人", position = 5 )
    private String auditPerson;
    /** 审核时间 */
    @ApiModelProperty(value = "审核时间", position = 7 )
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date auditDate;
}